@@ -8,11 +8,10 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         if len(args) != 1:
-            raise CommandError, "This command requires the slug of the " \
-                                "flatblock as its first argument"
+            raise CommandError("This command requires the slug of the "
+                               "flatblock as its first argument")
         slug = args[0]
         try:
             FlatBlock.objects.get(slug=slug).delete()
-        except FlatBlock.DoesNotExist, e:
-            raise CommandError, "The requested flatblock doesn't exist"
-
+        except FlatBlock.DoesNotExist:
+            raise CommandError("The requested flatblock doesn't exist")
