@@ -12,13 +12,20 @@ class FlatBlock(models.Model):
     title (header) which you can, for example, use in a sidebar of a website.
     """
     slug = models.CharField(max_length=255, unique=True,
-                verbose_name=_('Slug'),
-                help_text=_("A unique name used for reference in the templates"))
+                            verbose_name=_('Slug'),
+                            help_text=_("A unique name used for reference in "
+                                        "the templates"))
     header = models.CharField(blank=True, null=True, max_length=255,
-                verbose_name=_('Header'),
-                help_text=_("An optional header for this content"))
+                              verbose_name=_('Header'),
+                              help_text=_("An optional header for this "
+                                          "content"))
     content = models.TextField(verbose_name=_('Content'), blank=True,
-                null=True)
+                               null=True)
+
+    # Helper attributes used if content should be evaluated in order to
+    # represent the original content.
+    raw_content = None
+    raw_header = None
 
     def __unicode__(self):
         return u"%s" % (self.slug,)
@@ -28,6 +35,11 @@ class FlatBlock(models.Model):
         # Now also invalidate the cache used in the templatetag
         cache.delete('%s%s' % (CACHE_PREFIX, self.slug, ))
 
+    def delete(self, *args, **kwargs):
+        cache_key = '%s%s' % (CACHE_PREFIX, self.slug,)
+        super(FlatBlock, self).delete(*args, **kwargs)
+        cache.delete(cache_key)
+
     class Meta:
         verbose_name = _('Flat block')
         verbose_name_plural = _('Flat blocks')
